@@ -103,7 +103,6 @@ class TaskExtractor:
         Parse and convert the input_text to a list of tasks
         """
         result = []
-        input_text = input_text.lstrip('\n');
         line_number = 1
 
         pattern_task = re.compile('^(h5\.|h4\.|#[*#]?)\s+(.+)\s+\*(\w+)\*(?:\s+%(\d{4}-\d\d-\d\d)%)?(?:\s+({.+}))?(?:\s+\[(\w+)\])?')
@@ -128,7 +127,7 @@ class TaskExtractor:
                 else:
                     if pattern_json.match(line): # if json
                         self.tmpl_json.update(self._validated_json_loads(line))
-                    else:
+                    elif result:
                         result.append({'text':line})
             line_number += 1
         return result
@@ -211,11 +210,15 @@ class TaskExtractor:
                     if 'h5_task_key' in vars():
                         sub_task_caption = self._create_sub_task_and_return_caption(line, h5_task_key)
                         h5_task_ext = '\n'.join([h5_task_ext, sub_task_caption]) if h5_task_ext else sub_task_caption
+                    elif 'h4_task_key' in vars():
+                        sub_task_caption = self._create_sub_task_and_return_caption(line, h4_task_key)
+                        summary = "%s\n%s" % (summary, sub_task_caption) if summary else sub_task_caption
                     else:
                         sub_task_caption = self._create_sub_task_and_return_caption(line)
-                        summary = ('\n'.join([sub_task_caption, summary]) if summary else sub_task_caption)
+                        summary = "%s\n%s" % (summary, sub_task_caption) if summary else sub_task_caption
                 elif line['markup'] == 'h4.':
-                    h4_task = line
+                    h4_task_key, h4_task_caption = self._create_h4_task_and_return_key_caption(line)
+                    summary = ('\n'.join([h4_task_caption, summary]) if summary else h4_task_caption)
             elif 'text' in line:
                 h5_task_ext = '\n'.join([h5_task_ext, line['text']]) if h5_task_ext else line['text']
 
@@ -223,10 +226,6 @@ class TaskExtractor:
             h5_summary_list = self._h5_task_completion(h5_task_key, h5_task_caption, h5_task_desc, h5_task_ext)
             summary = '\n'.join([summary, h5_summary_list]) if summary else h5_summary_list
 
-        if 'h4_task' in vars():
-            h4_task_key, h4_task_caption = self._create_h4_task_and_return_key_caption(h4_task)
-            summary = ('\n'.join([h4_task_caption, summary]) if summary else h4_task_caption)
-
         return summary
 
 #####################################################################################
@@ -260,7 +259,7 @@ class TaskExtractor:
         return (h5_task_key, h5_task_caption, h5_task_desc)
 
     def _create_h4_task_and_return_key_caption(self, h4_task_json):
-        h4_task_json['issuetype'] = 'Epic Story'
+        h4_task_json['issuetype'] = 'User Story'
         h4_task_key = self.create_issue(h4_task_json)
         for key in self.h5_tasks_to_link_to_h4_task:
             self.create_link(h4_task_key, key)
@@ -291,7 +290,7 @@ class TaskExtractor:
 
         if not self.dry_run:
             try:
-                jira_response = str(self.jira_connect.post('issue', json.dumps(self.jira_format(issue))))
+                jira_response = self.jira_connect.post('issue', json.dumps(self.jira_format(issue)))
                 issueID = json.loads(jira_response)
                 return issueID['key']
             except JiraConnectActionError, e:
@@ -336,10 +335,10 @@ class TaskExtractor:
         """
 
         if method == 'POST':
-            return str(self.jira_connect.post(action, data))
+            return self.jira_connect.post(action, data)
         elif method == 'GET':
-            return str(self.jira_connect.get(action))
+            return self.jira_connect.get(action)
         elif method == 'PUT':
-            return str(self.jira_connect.put(action, data))
+            return self.jira_connect.put(action, data)
 
 
